@@ -7,11 +7,9 @@ OC.L10N.register(
     "A contacts app for Nextcloud" : "Nextcloud 연락처 앱",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 연락처 앱은 Nextcloud CardDAV 서버 사용자 인터페이스입니다. 다양한 장치의 주소록을 Nextcloud와 동기화하고 온라인으로 편집하십시오.\n\n* 🚀 **다른 Nextcloud 앱과 통합!** 현재 메일과 달력 앱과 통합되어 있으며 더 많은 앱을 지원할 예정입니다.\n* 🎉 **생일을 잊지 마세요!** Nextcloud 달력과 생일 및 반복되는 행사를 동기화할 수 있습니다.\n* 👥 **주소록을 공유하세요!** 친구나 동료와 주소록을 공유하고 싶으신가요? 문제 없습니다!\n* 🙈 **바퀴를 재발명하지 않습니다!** SabreDAV 라이브러리를 사용합니다.",
     "Copy to full name" : "전체 이름으로 복사",
+    "Omit year" : "연도 생략",
     "Allow updating avatars from social media" : "소셜 네트워크에서 아바타 업데이트를 허용",
-    "Please select a circle" : "서클을 선택하십시오",
-    "Loading circle …" : "서클 불러오는 중 ...",
-    "Your request to join this circle is pending approval" : "이 서클 등록 요청이 허가를 기다리고 있습니다",
-    "You are not a member of {circle}" : "당신은 {circle}의 회원이 아닙니다",
+    "You are not a member of {circle}" : "당신은 {circle}의 회원이 아닙니다.",
     "There was an error fetching the member list" : "회원 목록을 불러오는 중 오류 발생",
     "Loading contacts …" : "연락처 불러오는 중…",
     "There are no contacts yet" : "연락처 없음",
@@ -20,25 +18,25 @@ OC.L10N.register(
     "Create contacts" : "연락처 만들기",
     "Add contacts" : "연락처 추가",
     "Loading …" : "불러오는 중 …",
-    "Add member" : "회원 추가",
-    "Leave circle" : "서클 떠나기",
-    "Delete circle" : "서클 삭제",
-    "Download" : "다운로드",
+    "Contacts settings" : "연락처 설정",
+    "General settings" : "일반 설정",
+    "Update avatars from social media" : "소셜 네트워크에서 아바타 업데이트",
+    "(refreshed once per week)" : "(주 1회 새로고침)",
+    "Address books" : "주소록",
+    "Rename" : "이름 바꾸기",
+    "Export" : "내보내기",
     "Send email" : "이메일 보내기",
-    "Groups" : "그룹",
-    "Create a new group" : "새 그룹 생성",
-    "Group name" : "그룹 이름",
-    "Circles" : "서클",
-    "Create a new circle" : "새 서클 만들기",
+    "Send email as BCC" : "BCC로 이메일 보내기",
+    "Delete" : "삭제",
+    "Contact groups" : "연락처 그룹",
+    "Create a new contact group" : "새 연락처 그룹 생성",
+    "Contact group name" : "연락처 그룹 이름",
     "Show all groups" : "모든 그룹 보이기",
     "Collapse groups" : "그룹 접기",
-    "Show all circles" : "모든 서클 보이기",
-    "Collapse circles" : "서클 접기",
     "This group already exists" : "그룹이 이미 존재함",
-    "This circle already exists" : "서클이 이미 존재함",
-    "Rename" : "이름 바꾸기",
-    "Enabled" : "활성화됨",
-    "Delete" : "삭제",
+    "{addressbookname} (Disabled)" : "{addressbookname} (비활성화됨)",
+    "Download" : "다운로드",
+    "Show" : "보이기",
     "Copied" : "복사됨",
     "Cannot copy" : "복사할 수 없음",
     "Copy link" : "링크 복사",
@@ -46,17 +44,22 @@ OC.L10N.register(
     "Delete {addressbook}?" : "{addressbook}을(를) 삭제하시겠습니까?",
     "Deletion of address book was not successful." : "주소록 삭제에 실패했습니다.",
     "Renaming of address book was not successful." : "주소록 이름 변경에 실패했습니다.",
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num}명과 공유함"],
+    "_%n contact_::_%n contacts_" : ["연락처 %n개"],
+    "_%n group_::_%n groups_" : ["그룹 %n개"],
     "Share with users or groups" : "사용자 및 그룹과 공유",
+    "Share with users" : "사용자와 공유",
     "No users or groups" : "사용자나 그룹 없음",
     "can edit" : "편집 가능",
-    "Unable to delete the share" : "이 공유를 삭제할 수 없습니다",
+    "Unable to delete the share" : "이 공유를 삭제할 수 없습니다.",
     "Unable to change permissions" : "권한을 변경하지 못했습니다.",
     "Import contacts" : "연락처 가져오기",
     "Import into the {addressbookName} address book" : "{addressbookName} 주소록에 불러오기",
     "Select local file" : "로컬 파일 선택",
+    "Import from files" : "파일로부터 가져오기",
     "Importing is disabled because there are no address books available" : "주소록을 찾을 수 없어서 가져올 수 없습니다.",
-    "Choose a vCard file to import" : "불러올 vCard 파일을 고르세요",
+    "Choose a vCard file to import" : "불러올 vCard 파일을 고르기",
+    "Add new address book" : "새 주소록 생성",
+    "Add" : "Add",
     "An error occurred, unable to create the address book" : "오류가 발생하여 주소록을 생성할 수 없습니다.",
     "First name" : "이름",
     "Last name" : "성",
@@ -65,53 +68,63 @@ OC.L10N.register(
     "Display name" : "표시 이름",
     "Last modified" : "수정한 날짜",
     "Sort by {sorting}" : "{sorting}(으)로 정렬",
-    "Update avatars from social media" : "소셜 네트워크에서 아바타 업데이트",
-    "(refreshed once per week)" : "(주 1회 새로고침)",
     "An error happened during the config change" : "변경 사항을 설정하는 중 오류 발생",
     "Password protection" : "암호 보호",
+    "Unique password …" : "독자 암호 ...",
     "Save" : "저장",
-    "Circle name" : "서클 이름",
-    "Circle owned by {owner}" : "{owner} 님이 소유한 서클",
+    "Change unique password" : "독자 암호 변경",
+    "Failed to save password. Please try again later." : "암호를 저장하는 데 실패했습니다. 잠시 후 다시 시도하십시오.",
     "Request to join" : "등록 요청",
     "Description" : "설명",
-    "There is no description for this circle" : "이 서클에는 설명이 없음",
-    "Enter a description for the circle" : "이 서클에 대한 설명 입력",
+    "Settings" : "Settings",
     "An error happened during description sync" : "설명 동기화 중 오류 발생",
-    "Add new property" : "새 속성 추가",
-    "Choose property type" : "속성 종류 선택",
+    "An error happened during name sync" : "이름 동기화 중 오류 발생",
+    "Cancel" : "취소",
+    "Add more info" : "정보 추가",
+    "More fields" : "더 많은 입력란",
+    "Crop contact photo" : "연락처 사진 잘라내기",
     "Upload a new picture" : "새 그림 업로드",
     "Choose from Files" : "파일에서 선택",
-    "Get from " : "가져오기 - ",
     "Download picture" : "그림 다운로드",
     "Delete picture" : "그림 삭제",
+    "Please select a valid format" : "유효한 형식을 선택하십시오",
     "Invalid image" : "잘못된 사진",
-    "Image is too big (max 1MB)." : "그림이 너무 큽니다(최대 1MB).",
+    "Error cropping picture" : "연락처 사진을 잘라내던 중 오류 발생",
     "Pick an avatar" : "아바타 선택",
     "Error while processing the picture." : "그림을 처리하는 중 오류가 발생했습니다.",
-    "Avatar downloaded from social network" : "소셜 네트워크에서 아바타가 다운로드 되었습니다",
-    "Avatar already up to date" : "아바타가 이미 업데이트 되었습니다",
+    "Avatar downloaded from social network" : "소셜 네트워크에서 아바타가 다운로드 되었습니다.",
+    "Avatar already up to date" : "아바타가 이미 업데이트 되었습니다.",
     "Avatar download failed" : "아바타 다운로드 실패",
     "No contact selected" : "선택한 연락처 없음",
-    "Select a contact on the list to begin" : "목록에서 연락처를 선택하여 시작하십시오",
+    "Select a contact on the list to begin" : "목록에서 연락처를 선택하여 시작하세요.",
     "Name" : "이름",
-    "Company" : "회사",
     "Title" : "직위",
+    "Company" : "회사",
+    "Go to talk conversation" : "Talk 대화로 이동",
+    "View profile" : "프로필 보기",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "연락처가 잘못되었으며 수정이 필요합니다. 내용을 점검하고 여기를 눌러 저장하십시오.",
+    "Edit" : "편집",
     "Clone contact" : "연락처 복제",
     "Generate QR Code" : "QR 코드 생성",
     "Contact vCard as QR code" : "QR 코드로 된 vCard 연락처",
-    "Pick an address book" : "주소록을 선택하세요",
+    "Pick an address book" : "주소록 선택",
     "Select address book" : "주소록 선택",
-    "Cancel" : "취소",
-    "This contact is not yet synced. Edit it to save it to the server." : "이 연락처를 동기화하지 않았습니다. 편집하면 서버에 저장합니다.",
+    "Media shares with you" : "나와 공유된 미디어",
+    "Talk conversations with you" : "나와의 Talk 대화",
+    "Calendar events with you" : "나와의 달력 일정",
+    "No shared items with this contact" : "이 연락처와 공유된 항목 없음",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "이 연락처는 읽기 전용 모드입니다. 편집할 수 있는 권한이 없습니다.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "편집하려고 하는 연락처가 변경되었습니다. 연락처를 직접 새로 고치십시오. 추가 변경 사항은 손실됩니다.",
     "Address book" : "주소록",
-    "New contact" : "새 연락처",
+    "Add contact to Birthday Calendar" : "연락처를 생일 달력에 추가",
+    "Exclude contact from Birthday Calendar" : "생일 달력에서 연락처 제외",
+    "{title} at {organization}" : "{organization}의 {title}",
     "Syntax error. Cannot open the contact." : "문법 오류입니다. 연락처를 열 수 없습니다.",
+    "The contact does not exist on the server anymore." : "연락처가 서버에 더 이상 존재하지 않습니다.",
     "Unable to retrieve the contact from the server, please check your network connection." : "연락처를 가져올 수 없습니다. 네트워크 연결을 확인하세요.",
     "An error occurred while trying to move the contact" : "연락처를 이동하는 중 오류 발생",
     "An error occurred while trying to copy the contact" : "연락처를 복사하는 중 오류 발생",
+    "Unable to update contact" : "연락처를 갱신할 수 없음",
     "Search contacts …" : "연락처 검색…",
     "Add to {group}" : "{group}에 추가",
     "Remove {type}" : "{type} 삭제",
@@ -120,57 +133,45 @@ OC.L10N.register(
     "No results" : "결과 없음",
     "Add to group" : "그룹에 추가",
     "Add {type}" : "{type} 추가",
-    "New circle name" : "새 서클 이름",
-    "Personal circle" : "개인 서클",
-    "This circle will only be visible to you. Other members will not be able to see or use it." : "이 서클은 당신에게만 보입니다. 다른 회원은 보거나 이용할 수 없습니다.",
-    "Local circle" : "로컬 서클",
-    "Create circle" : "서클 만들기",
     "Loading members list …" : "회원 목록 불러오는 중 ...",
-    "There is no member in this circle" : "이 서클에는 회원이 없음",
+    "You currently have no access to the member list" : "현재 이 구성원 목록에 접근할 수 없습니다",
     "Add members" : "회원 추가",
-    "Show circle details" : "서클 자세히 보기",
     "Add to {circle}" : "{circle}에 추가",
     "Unable to get the recommendations list" : "추천 목록을 받아올 수 없음",
     "Unable to get the results" : "결과를 받아올 수 없음",
     "Some members could not be added" : "일부 회원을 추가할 수 없음",
-    "There was an issue adding members to the circle" : "서클에 회원을 추가하는 중 문제 발생",
+    "Accept membership request" : "가입 요청 수락",
+    "Reject membership request" : "가입 요청 거절",
     "Manage level" : "레벨 관리",
     "Remove member" : "회원 삭제",
     "Pending" : "보류 중",
-    "Promote as sole owner" : "단독 소유자 지정",
-    "Promote to {level}" : "{level}(으)로 상향",
-    "Demote to {level}" : "{level}(으)로 하향",
-    "Could not delete the member {displayName}" : "{displayName} 회원을 삭제할 수 없습니다",
-    "Could not change the member level to {level}" : "회원 레벨을 {level}로 바꿀 수 없습니다",
+    "Promote as sole owner" : "단독 소유 권한 부여",
+    "Promote to {level}" : "{level}(으)로 진급",
+    "Demote to {level}" : "{level}(으)로 강등",
+    "Could not delete the member {displayName}" : "{displayName} 회원을 삭제할 수 없습니다.",
+    "Could not change the member level to {level}" : "회원 레벨을 {level}로 바꿀 수 없습니다.",
+    "Could not accept membership request" : "가입 요쳥을 수락할 수 없습니다",
+    "Chart" : "차트",
+    "Select chart …" : "차트 선택 ...",
     "Select type" : "종류 선택",
     "Select Date" : "날짜 선택",
     "Add contact in group" : "그룹에 연락처 추가",
+    "None" : "없음",
     "Select option" : "옵션 선택",
+    "New contact" : "새 연락처",
     "Unable to create the contact." : "연락처를 만들 수 없습니다.",
     "Contact not found" : "연락처를 찾을 수 없음",
     "Group {group} not found" : "그룹 {group}을(를) 찾을 수 없음",
     "Close" : "닫기",
-    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 연락처를 {name}에 추가하는 중"],
-    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 연락처를 {name}에 추가하는 중"],
-    "_{count} error_::_{count} errors_" : ["{count} 오류 발생"],
-    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{addressbook}에 %n 연락처를 가져오는 중"],
-    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{addressbook}에 %n 연락처 가져오기 완료"],
     "Import" : "가져오기",
     "Could not copy" : "복사할 수 없음",
-    "Join circle" : "서클 가입",
     "You are about to leave {circle}.\nAre you sure?" : "{circle} 서클에서 정말 떠나시겠습니까?",
-    "Please confirm circle leave" : "서클 떠나기를 확인해주십시오",
-    "Could not leave the circle {displayName}" : "[displayName} 서클을 떠날 수 없습니다",
-    "Unable to join the circle" : "서클에 등록할 수 없음",
     "You are about to delete {circle}.\nAre you sure?" : "{circle} 서클을 정말 삭제하시겠습니까?",
-    "Please confirm circle deletion" : "서클 삭제를 확인해주십시오",
-    "Unable to delete the circle" : "서클을 삭제할 수 없습니다",
     "Link copied to the clipboard" : "링크가 클립보드에 복사됨",
     "Could not copy link to the clipboard." : "링크를 클립보드에 복사할 수 없음",
     "Not grouped" : "그룹되지 않음",
     "Recently contacted" : "최근 연락함",
-    "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "서클을 통해 다른 사용자와 Nextcloud 인스턴스에서 그룹을 만들고 공유할 수 있습니다.",
-    "Circle" : "서클",
+    "Organization chart" : "조직도",
     "User" : "사용자",
     "Group" : "그룹",
     "Email" : "이메일",
@@ -182,19 +183,14 @@ OC.L10N.register(
     "Invites" : "초대",
     "Anyone can request membership" : "누구나 가입을 요청할 수 있음",
     "Members need to accept invitation" : "회원이 초대를 수락해야 함",
-    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "중재자가 회원 가입을 확인/수락해야 함 (요청 가능)",
     "Members can also invite" : "회원도 초대 가능",
     "Visibility" : "표시 여부",
     "Visible to everyone" : "모두에게 보이기",
-    "Circle membership" : "서클 회원",
-    "Prevent circle from being a member of another circle" : "이 서클이 다른 서클의 회원이 될 수 없음",
-    "Users" : "사용자",
-    "Emails" : "이메일",
-    "Nickname" : "별명",
     "Detailed name" : "자세한 이름",
     "Additional names" : "추가 이름",
     "Prefix" : "접두사",
     "Suffix" : "접미사",
+    "Nickname" : "별명",
     "Notes" : "메모",
     "Website" : "웹 사이트",
     "Location" : "위치",
@@ -224,7 +220,6 @@ OC.L10N.register(
     "Voice" : "음성 번호",
     "Car" : "카폰",
     "Work pager" : "직장 호출기",
-    "Manager" : "관리자",
     "Social network" : "소셜 네트워크",
     "Relationship to you" : "나와의 관계",
     "Spouse" : "배우자",
@@ -245,13 +240,12 @@ OC.L10N.register(
     "Gender" : "성별",
     "Female" : "여성",
     "Male" : "남성",
-    "None" : "없음",
     "Unknown" : "알 수 없음",
+    "Time zone" : "시간대",
     "Spoken languages" : "사용 언어",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["연락처 {failed}개를 읽을 수 없음"],
-    "Some circle(s) an error occurred. Check the console for more details." : "일부 서클에서 오류가 발생함. 자세한 사항은 콘솔 참조하십시오.",
-    "Unable to create circle {circleName}" : "{circleName} 서클을 만들 수 없음",
-    "Unable to delete circle {circleId}" : "{circleId} 서클을 삭제할 수 없음",
-    "Unable to delete contact" : "연락처를 삭제할 수 없음"
+    "Unable to delete contact" : "연락처를 삭제할 수 없음",
+    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "중재자가 회원 가입을 확인 및 수락해야 합니다. (요청 가능)",
+    "Manager" : "관리자"
 },
 "nplurals=1; plural=0;");
